pub struct BuiltinSerializationError {
pub rust_name: &'static str,
pub kind: BuiltinSerializationErrorKind,
}Expand description
Failed to serialize values for a statement, represented by one of the types built into the driver.
Fields
rust_name: &'static strName of the Rust type used to represent the values.
kind: BuiltinSerializationErrorKindDetailed information about the failure.